@@ -19,9 +19,9 @@ ar.act1  <- function(y) {
   # Make sure y is a vector and has at least enough distinct elements
   # to estimate an AR(1) model.
 
-  stopifnot(NCOL(y)==1)
-  if (length(unique(y))<5)
-    return(list(act=NA, act.025=NA, act.975=NA, se=NA, order=NA))
+  stopifnot(NCOL(y) == 1)
+  if (length(unique(y)) < 5)
+    return(list(act = NA, act.025 = NA, act.975 = NA, se = NA, order = NA))
 
   # First try arbitrary AIC-chosen order.  If the conditioning on
   # the asymptotic covariance matrix is problematic, choose a smaller
@@ -32,39 +32,42 @@ ar.act1  <- function(y) {
 
   order.max <- NULL
   repeat {
-    A <- ar.yw(y, demean=FALSE, order.max=order.max)
-    if (A$order==0)   # force an order of at least one
-      A <- ar.yw(y, demean=FALSE, order.max=1, aic=FALSE)
+    A <- ar.yw(y, demean = FALSE, order.max = order.max)
+    if (A$order == 0)   # force an order of at least one
+      A <- ar.yw(y, demean = FALSE, order.max = 1, aic = FALSE)
 
     pi <- A$ar
     pi.var <- A$asy.var.coef
-    if (kappa(pi.var)<1/sqrt(.Machine$double.eps) || isTRUE(order.max==1))
+    if (kappa(pi.var) < 1 / sqrt(.Machine$double.eps) ||
+        isTRUE(order.max == 1)) {
       break
+    }
     order.max <- floor(A$order * 0.7)
   }
 
   # Use the AR model to compute the autocorrelation time and its
-  # CI.  The SE and CI are not equivalent because the CI is asymmetric.
+  # CI. The SE and CI are not equivalent because the CI is asymmetric.
 
-  acf <- matrix(ARMAacf(ar=pi)[2:(A$order+1)])
-  act <- (1-sum(pi*acf))/(1-sum(pi))^2
+  acf <- matrix(ARMAacf(ar = pi)[2:(A$order + 1)])
+  act <- (1 - sum(pi * acf)) / (1 - sum(pi)) ^ 2
 
   # Draw from asymptotic distribution of AR coefs.  Uses SVD because
   # pi.var can be ill-conditioned.
 
   simulation.length <- min(max(40, length(y)), 5000)
-  AX <- mvtnorm::rmvnorm(simulation.length, mean=pi, sigma=pi.var, method='svd')
+  AX <- mvtnorm::rmvnorm(simulation.length, mean = pi, sigma = pi.var,
+                         method = "svd")
   act.sim <- numeric(simulation.length)
 
   # Compute simulation.length estimates of the ACT.
 
   for (i in 1:simulation.length) {
-    pi.sim <- AX[i,]
-    acf.sim <- ARMAacf(ar=pi.sim)[2:(A$order+1)]
-    if (any(abs(polyroot(c(-1,pi.sim)))<1))        # stationary process?
+    pi.sim <- AX[i, ]
+    acf.sim <- ARMAacf(ar = pi.sim)[2:(A$order + 1)]
+    if (any(abs(polyroot(c(-1, pi.sim))) < 1))        # stationary process?
       act.sim[i] <- Inf
     else
-      act.sim[i] <- (1-sum(pi.sim*acf.sim))/(1-sum(pi.sim))^2
+      act.sim[i] <- (1 - sum(pi.sim * acf.sim)) / (1 - sum(pi.sim)) ^ 2
   }
 
   # Compute ACT quantiles.
@@ -72,20 +75,21 @@ ar.act1  <- function(y) {
   act.sim[is.na(act.sim)] <- Inf
   act.025 <- as.numeric(quantile(act.sim, 0.025))   # as.numeric to drop name
   act.975 <- as.numeric(quantile(act.sim, 0.975))   # as.numeric to drop name
-  se <- (act.975-act.025)/(2*1.96)
+  se <- (act.975 - act.025) / (2 * 1.96)
 
-  return(list(act=act, se=se, act.025=act.025, act.975=act.975, order=A$order))
+  return(list(act = act, se = se, act.025 = act.025, act.975 = act.975,
+              order = A$order))
 }
 
 # See ?ar.act for more information.
 
-ar.act <- function(Y, true.mean=NULL) {
+ar.act <- function(Y, true.mean = NULL) {
 
   # Check that parameters are reasonable and estimate mean and
   # variances if they were not specified.
 
   Y <- as.matrix(Y)
-  stopifnot(is.null(true.mean) || ncol(Y)==length(true.mean))
+  stopifnot(is.null(true.mean) || ncol(Y)  == length(true.mean))
 
   if (is.null(true.mean))
     mu <- colMeans(Y)
@@ -96,10 +100,10 @@ ar.act <- function(Y, true.mean=NULL) {
   # ar.act1.  Return the act, CI, and SE for the slowest-mixing
   # component.
 
-  acts <- sapply(1:ncol(Y), function(i) ar.act1(Y[,i]-mu[i]))
-  max.i <- which.max(unlist(acts['act',]))
-  if (length(max.i)!=1)   # happens if all ACTs are NA
-    return(list(act=NA, act.025=NA, act.975=NA, se=NA, order=NA))
+  acts <- sapply(1:ncol(Y), function(i) ar.act1(Y[, i] - mu[i]))
+  max.i <- which.max(unlist(acts["act", ]))
+  if (length(max.i) != 1 )   # happens if all ACTs are NA
+    return(list(act = NA, act.025 = NA, act.975 = NA, se = NA, order = NA))
   else
-    return(acts[,max.i])
+    return(acts[, max.i])
 }
